@@ -107,7 +107,7 @@ class Jp2kr(Jp2kBox):
         if not self.path.exists():
             raise FileNotFoundError(f"{self.filename} does not exist.")
 
-        self.parse()
+        self._parse()
         self._initialize_shape()
 
     def _initialize_shape(self):
@@ -393,6 +393,15 @@ class Jp2kr(Jp2kBox):
         return "\n".join(metadata)
 
     def parse(self, force=False):
+        """
+        .. deprecated:: 0.15.0
+        """
+        breakpoint()
+        msg = "Deprecated, do not use."
+        warnings.warn(msg, DeprecationWarning)
+        self._parse(force=force)
+
+    def _parse(self, force=False):
         """Parses the JPEG 2000 file.
 
         Parameters
@@ -633,25 +642,6 @@ class Jp2kr(Jp2kBox):
         # Ok, 3 arguments in pargs.
         return data[:, :, bands]
 
-    def read(self, **kwargs):
-        """Read a JPEG 2000 image.
-
-        .. deprecated:: 0.13.5
-           Use numpy-style slicing instead.
-
-        Returns
-        -------
-        img_array : ndarray
-            The image data.
-        """
-
-        if "ignore_pclr_cmap_cdef" in kwargs:
-            self.ignore_pclr_cmap_cdef = kwargs["ignore_pclr_cmap_cdef"]
-            kwargs.pop("ignore_pclr_cmap_cdef")
-        warnings.warn("Use array-style slicing instead.", DeprecationWarning)
-        img = self._read(**kwargs)
-        return img
-
     def _subsampling_sanity_check(self):
         """Check for differing subsample factors."""
         if self._decoded_components is None:
@@ -854,7 +844,7 @@ class Jp2kr(Jp2kBox):
 
         The only time you should ever use this method is when the image has
         different subsampling factors across components.  Otherwise you should
-        use the read method.
+        use numpy-style slicing.
 
         Parameters
         ----------
@@ -966,7 +956,7 @@ class Jp2kr(Jp2kBox):
         return image
 
     def _component2dtype(self, component):
-        """Determin the appropriate numpy datatype for an OpenJPEG component.
+        """Determine the appropriate numpy datatype for an OpenJPEG component.
 
         Parameters
         ----------
