@@ -16,11 +16,11 @@ import numpy as np
 
 # Local imports ...
 from .lib import openjp2 as opj2
-from .lib import tiff
+from .lib import _tiff as tiff
 
 # Do not change the format of this next line!  Doing so risks breaking
 # setup.py
-version = "0.14.1"
+version = "0.14.3"
 
 version_tuple = parse(version).release
 
